<?php
/**
 * Functions for user registration
 * @since 1.7.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Check activation setting
 * @since 1.7.0
 */
function ctdb_pro_deregister_actions() {
	$require_activation = ctdb_get_activation_setting();
	if( $require_activation == 'admin' ) {
		// If registrations require admin approval, remove filters to send emails
		remove_action( 'ctdb_email_admin_new_registration', 'ctdb_send_admin_email_new_registration', 10 );
		remove_action( 'ctdb_email_user_activation_key', 'ctdb_email_user_after_registration', 10 );
		// Send different emails
		add_action( 'ctdb_email_user_activation_key', 'ctdb_pro_email_admin_for_approval', 10, 3 );
	}
}
add_action( 'init', 'ctdb_pro_deregister_actions', 1 );

/**
 * Send admin email to approve new user account
 * @param $new_user_id User ID
 * @param $user_email User email
 * @param $require_activation Activation setting
 * @since 2.2.12
 */
if ( ! function_exists ( 'ctdb_pro_email_admin_for_approval' ) ) {
	
	function ctdb_pro_email_admin_for_approval( $new_user_id, $user_email, $require_activation ) {

		// Add an activation key as usermeta
		$key = substr( md5( time() . rand() ), 0, 16 );
		add_user_meta( $new_user_id, 'activate_key', sanitize_text_field( $key ) );

		// Email the user
		// Set HTML content type
		add_filter( 'wp_mail_content_type', 'ctdb_set_html_content_type' );
		
		$user = get_userdata( $new_user_id );

		$to = ctdb_get_admin_email();
		$subject = get_bloginfo( 'name' ) . ': ' . __( 'Approve new user', 'discussion-board-pro' );
		$message = '<p>' . __( 'A new user has registered on the site. Please approve or reject this registration by clicking one of the links below:', 'discussion-board-pro' ) . '</p>';
		
		$message .= '<table><tbody>';
		$message .= '<tr>';
			$message .= sprintf( '<td>%s</td>', __( 'Username', 'discussion-board-pro' ) );
			$message .= sprintf( '<td>%s</td>', esc_html( $user->user_login ) );
		$message .= '</tr>';
		$message .= '<tr>';
			$message .= sprintf( '<td>%s</td>', __( 'Email address', 'discussion-board-pro' ) );
			$message .= sprintf( '<td>%s</td>', esc_html( $user->user_email ) );
		$message .= '</tr>';
		$message .= '<tr>';
			$message .= sprintf( '<td>%s</td>', __( 'First name', 'discussion-board-pro' ) );
			$message .= sprintf( '<td>%s</td>', esc_html( $user->first_name ) );
		$message .= '</tr>';
		$message .= '<tr>';
			$message .= sprintf( '<td>%s</td>', __( 'Last name', 'discussion-board-pro' ) );
			$message .= sprintf( '<td>%s</td>', esc_html( $user->last_name ) );
		$message .= '</tr>';
		$message .= '</tbody></table>';

		// Get the current URL and append the activation code and user ID
		$url = admin_url( 'user-edit.php' );
		
		$view_url = add_query_arg(
			array(
				'user_id'		=> $new_user_id
			),
			$url
		);
		$url = add_query_arg(
			array(
				'admin_activate_code'	=> $key,
				'user_id'				=> $new_user_id
			),
			$url
		);

		$message .= sprintf( '<p><a href="%s">%s</a></p>', esc_url( $url ), __( 'Approve user', 'discussion-board-pro' ) );
		$message .= sprintf( '<p><a href="%s">%s</a></p>', esc_url( $view_url ), __( 'View user', 'discussion-board-pro' ) );

		// Set HTML content type
		add_filter( 'wp_mail_content_type', 'ctdb_set_html_content_type' );

		wp_mail( $to, $subject, $message );

		// Reset content-type to avoid conflicts -- http://core.trac.wordpress.org/ticket/23578
		remove_filter( 'wp_mail_content_type', 'ctdb_set_html_content_type' );

	}
}

/**
 * Filter the message for new user after submitting registration form
 * @param $$success Message
 * @param $require_activation Activation setting
 * @since 2.2.12
 */
if ( ! function_exists ( 'ctdb_pro_approval_required_message' ) ) {
	function ctdb_pro_approval_required_message( $success, $require_activation ) {
		if( $require_activation == 'admin' ) {
			return __( 'Thank you for registering. You will receive an email once your registration has been approved.', 'discussion-board-pro' );
		}
		return $success;
	}
}
add_filter( 'ctdb_filter_registration_message', 'ctdb_pro_approval_required_message', 10, 2 );